===================================================
 oslo.vmware --- VMware support code for OpenStack
===================================================

The Oslo VMware library provides support for common VMware operations
and APIs.

.. toctree::
   :maxdepth: 2

   installation
   usage
   contributing

Code Documentation
==================

.. toctree::
   :maxdepth: 1

   api/autoindex

Release Notes
=============

.. toctree::
   :maxdepth: 1

   history


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
